==> django-generic-rest-0.2.5.tar.gz: django-generic-rest-0.2.5/generic/repositories.py <==
from django.core.exceptions import ObjectDoesNotExist

from utility.exceptions import ObjectNotFoundError
from utility.functions import contains_char_classes, is_email_valid


class GenericRepository():
    """
    Provides a generic database abstraction layer that does not depend on
    the model class
    """
    def __init__(self, model_class):
        """
        Constructor
        """
        self.model_class = model_class

    def find_by_user(self, user):
        """
        Provides generic find by user function
        """
        if hasattr(self.model_class, 'owner'):
            return self.model_class.objects.filter(owner=user)

        try:
            return self.model_class.objects.filter(id=user.id)
        except AttributeError:
            raise ObjectNotFoundError('No object matching user found.',
                                      modelclass=self.model_class)

    def find_by_id(self, pk, user):
        """
        Provides generic find by id function
        """
        if hasattr(self.model_class, 'owner'):
            return self.model_class.objects.filter(owner=user).filter(id=pk)

        try:
            return self.model_class.objects.filter(id=user.id).filter(id=pk)
        except AttributeError:
            raise ObjectNotFoundError('No object matching user found.',
                                      modelclass=self.model_class)

    def get_by_id(self, pk, user):
        """
        Provides generic get by id function
        """
        if hasattr(self.model_class, 'owner'):
            try:
                return self.model_class.objects.filter(owner=user).get(id=pk)
            except ObjectDoesNotExist:
                raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

        try:
            return self.model_class.objects.filter(id=user.id).get(id=pk)
        except AttributeError:
            raise ObjectNotFoundError('No object matching user found.',
                                      modelclass=self.model_class)
        except ObjectDoesNotExist:
            raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

    def get_by_user_and_id(self, pk, user):
        """
        Provides generic get by user and id function
        """
        if hasattr(self.model_class, 'owner'):
            try:
                return self.model_class.objects.filter(owner=user).get(id=pk)
            except ObjectDoesNotExist:
                raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

        try:
            return self.model_class.objects.filter(id=user.id).get(id=pk)
        except AttributeError:
            raise ObjectNotFoundError('No object matching user found.',
                                      modelclass=self.model_class)
        except ObjectDoesNotExist:
            raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

    def list_all(self):
        """
        Provides generic list all function
        """
        return self.model_class.objects.all()

    def delete_by_id(self, pk, user):
        """
        Provides generic delete function
        """
        if hasattr(self.model_class, 'owner'):
            try:
                return self.model_class.objects.filter(owner=user).get(id=pk).delete()
            except ObjectDoesNotExist:
                raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

        try:
            return self.model_class.objects.filter(id=user.id).get(id=pk).delete()
        except AttributeError:
            raise ObjectNotFoundError('No object matching user found.',
                                      modelclass=self.model_class)
        except ObjectDoesNotExist:
            raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

    @staticmethod
    def persist(instance):
        """
        Provides generic persist function
        """
        return instance.save()

    def check_unique(self, pk, field, value):
        """
        Checks the uniqueness of value
        """
        if value is None:
            return 0

        kwargs = {field: str(value)}
        return self.model_class.objects.exclude(id=pk).filter(**kwargs)

    @staticmethod
    def check_password_too_short(password, length):
        """
        Checks if password is at least as long as length demands
        """
        if len(password) < length:
            return True

        return False

    @staticmethod
    def check_too_few_char_classes(password, noc):
        """
        Checks if password contains the demanded number of different
        char classes
        """
        if not contains_char_classes(password, noc):
            return True

        return False

    @staticmethod
    def check_email_valid(email):
        """
        Checks if an email address is valid
        """
        return email is None or is_email_valid(email)

==> django-generic-rest-0.3.1.tar.gz: django-generic-rest-0.3.1/generic/repositories.py <==
from django.core.exceptions import ObjectDoesNotExist

from utility.exceptions import ObjectNotFoundError
from utility.functions import contains_char_classes, is_email_valid


class GenericRepository():
    """
    Provides a generic database abstraction layer that does not depend on
    the model class
    """

    def __init__(self, model_class):
        """
        Constructor
        """
        self.model_class = model_class

    def find_by_user(self, user):
        """
        Provides generic find by user function
        """
        if hasattr(self.model_class, 'owner'):
            return self.model_class.objects.filter(owner=user)

        try:
            return self.model_class.objects.filter(id=user.id)
        except AttributeError:
            raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

    def find_by_id(self, pk, user):
        """
        Provides generic find by id function
        """
        if hasattr(self.model_class, 'owner'):
            return self.model_class.objects.filter(owner=user).filter(id=pk)

        try:
            return self.model_class.objects.filter(id=user.id).filter(id=pk)
        except AttributeError:
            raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

    def get_by_id(self, pk, user):
        """
        Provides generic get by id function
        """
        if hasattr(self.model_class, 'owner'):
            try:
                return self.model_class.objects.filter(owner=user).get(id=pk)
            except ObjectDoesNotExist:
                raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

        try:
            return self.model_class.objects.filter(id=user.id).get(id=pk)
        except (ObjectDoesNotExist, AttributeError):
            raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

    def get_by_user_and_id(self, pk, user):
        """
        Provides generic get by user and id function
        """
        if hasattr(self.model_class, 'owner'):
            try:
                return self.model_class.objects.filter(owner=user).get(id=pk)
            except ObjectDoesNotExist:
                raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

        try:
            return self.model_class.objects.filter(id=user.id).get(id=pk)
        except (ObjectDoesNotExist, AttributeError):
            raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

    def list_all(self):
        """
        Provides generic list all function
        """
        return self.model_class.objects.all()

    def list_all(self):
        """
        Provides generic list all function
        """
        return self.model_class.objects.all()

    def delete_by_id(self, pk, user):
        """
        Provides generic delete function
        """
        if hasattr(self.model_class, 'owner'):
            try:
                return self.model_class.objects.filter(owner=user).get(id=pk).delete()
            except ObjectDoesNotExist:
                raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

        try:
            return self.model_class.objects.filter(id=user.id).get(id=pk).delete()
        except (ObjectDoesNotExist, AttributeError):
            raise ObjectNotFoundError('Object not found.', modelclass=self.model_class)

    @staticmethod
    def persist(instance):
        """
        Provides generic persist function
        """
        return instance.save()

    def check_unique(self, instance, field):
        """
        Checks the uniqueness of value
        """
        value = getattr(instance, field)
        if value is None:
            return 0

        kwargs = {field: str(value)}
        pk = getattr(instance, 'id')
        return self.model_class.objects.exclude(id=pk).filter(**kwargs)

    @staticmethod
    def is_none(instance, field):
        """
        Checks if the passed value is None
        Can be used as argument validator
        """
        try:
            if type(instance) is dict:
                value = instance[field]
            else:
                value = getattr(instance, field)

        except KeyError:
            return True

        if value is None:
            return True

        return False

    @staticmethod
    def value_too_long(instance, field, length):
        """
        Checks if value is longer then max_length
        Can be used as argument validator
        """
        try:
            if type(instance) is dict:
                value = instance[field]
            else:
                value = getattr(instance, field)

        except KeyError:
            return False

        if value is None:
            return False

        if len(value) > length:
            return True

        return False

    @staticmethod
    def contains_arg(instance, field):
        """
        Checks if field is present in the args dictionary
        Can be used as argument validator
        """
        try:
            if type(instance) is dict:
                instance[field]
            else:
                getattr(instance, field)
            return True

        except KeyError:
            return False

    @staticmethod
    def check_password_too_short(password, length):
        """
        Checks if password is at least as long as length demands
        """
        if len(password) < length:
            return True

        return False

    @staticmethod
    def check_too_few_char_classes(password, noc):
        """
        Checks if password contains the demanded number of different
        char classes
        """
        if not contains_char_classes(password, noc):
            return True

        return False

    @staticmethod
    def check_email_valid(email):
        """
        Checks if an email address is valid
        """
        return email is None or is_email_valid(email)
